# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: monitor_filesystem.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='monitor_filesystem.proto',
    package='',
    syntax='proto2',
    serialized_pb=_b(
        '\n\x18monitor_filesystem.proto\"\xd4\x01\n\x12monitor_filesystem\x12\x0f\n\x07scan_id\x18\x01 \x02(\x05\x12\x10\n\x08\x66ilename\x18\x02 \x02(\t\x12\x0b\n\x03pid\x18\x03 \x02(\x05\x12\x0b\n\x03uid\x18\x04 \x02(\x05\x12\x0b\n\x03gid\x18\x05 \x02(\x05\x12\x0c\n\x04mode\x18\x06 \x02(\x05\x12\x0c\n\x04ppid\x18\x07 \x02(\x05\x12\x0c\n\x04proc\x18\x08 \x02(\t\x12\x0c\n\x04type\x18\t \x02(\t\x12\x12\n\nuser_right\x18\n \x02(\t\x12\x13\n\x0bgroup_right\x18\x0b \x02(\t\x12\x13\n\x0bother_right\x18\x0c \x02(\t')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_MONITOR_FILESYSTEM = _descriptor.Descriptor(
    name='monitor_filesystem',
    full_name='monitor_filesystem',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='scan_id', full_name='monitor_filesystem.scan_id', index=0,
            number=1, type=5, cpp_type=1, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='filename', full_name='monitor_filesystem.filename', index=1,
            number=2, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='pid', full_name='monitor_filesystem.pid', index=2,
            number=3, type=5, cpp_type=1, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='uid', full_name='monitor_filesystem.uid', index=3,
            number=4, type=5, cpp_type=1, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='gid', full_name='monitor_filesystem.gid', index=4,
            number=5, type=5, cpp_type=1, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='mode', full_name='monitor_filesystem.mode', index=5,
            number=6, type=5, cpp_type=1, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='ppid', full_name='monitor_filesystem.ppid', index=6,
            number=7, type=5, cpp_type=1, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='proc', full_name='monitor_filesystem.proc', index=7,
            number=8, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='type', full_name='monitor_filesystem.type', index=8,
            number=9, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='user_right', full_name='monitor_filesystem.user_right', index=9,
            number=10, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='group_right', full_name='monitor_filesystem.group_right', index=10,
            number=11, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='other_right', full_name='monitor_filesystem.other_right', index=11,
            number=12, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    options=None,
    is_extendable=False,
    syntax='proto2',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=29,
    serialized_end=241,
)

DESCRIPTOR.message_types_by_name['monitor_filesystem'] = _MONITOR_FILESYSTEM

monitor_filesystem = _reflection.GeneratedProtocolMessageType('monitor_filesystem', (_message.Message,), dict(
    DESCRIPTOR=_MONITOR_FILESYSTEM,
    __module__='monitor_filesystem_pb2'
    # @@protoc_insertion_point(class_scope:monitor_filesystem)
))
_sym_db.RegisterMessage(monitor_filesystem)

# @@protoc_insertion_point(module_scope)
