# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ide_request.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='ide_request.proto',
    package='',
    serialized_pb=_b(
        '\n\x16request_response.proto\"%\n\x06header\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\r\n\x05value\x18\x02 \x02(\t\"N\n\x07request\x12\x0e\n\x06method\x18\x01 \x02(\t\x12\x0b\n\x03url\x18\x02 \x02(\t\x12\x18\n\x07headers\x18\x03 \x03(\x0b\x32\x07.header\x12\x0c\n\x04\x62ody\x18\x04 \x01(\x0c\"\x9e\x01\n\x08response\x12\x0b\n\x03url\x18\x01 \x02(\t\x12\x0e\n\x06status\x18\x02 \x02(\x05\x12\x13\n\x0bstatus_text\x18\x03 \x02(\t\x12\x18\n\x07headers\x18\x04 \x03(\x0b\x32\x07.header\x12\x11\n\tremote_ip\x18\x05 \x01(\t\x12\x13\n\x0bremote_port\x18\x06 \x01(\x05\x12\x10\n\x08protocol\x18\x07 \x01(\t\x12\x0c\n\x04\x62ody\x18\x08 \x01(\x0c\"[\n\x10request_response\x12\x0f\n\x07scan_id\x18\x01 \x02(\x05\x12\x19\n\x07request\x18\x02 \x02(\x0b\x32\x08.request\x12\x1b\n\x08response\x18\x03 \x01(\x0b\x32\t.response')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_HEADER = _descriptor.Descriptor(
    name='header',
    full_name='header',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='name', full_name='header.name', index=0,
            number=1, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='value', full_name='header.value', index=1,
            number=2, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    options=None,
    is_extendable=False,
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=26,
    serialized_end=63,
)

_REQUEST = _descriptor.Descriptor(
    name='request',
    full_name='request',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='method', full_name='request.method', index=0,
            number=1, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='url', full_name='request.url', index=1,
            number=2, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='headers', full_name='request.headers', index=2,
            number=3, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='body', full_name='request.body', index=3,
            number=4, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    options=None,
    is_extendable=False,
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=65,
    serialized_end=143,
)

_RESPONSE = _descriptor.Descriptor(
    name='response',
    full_name='response',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='url', full_name='response.url', index=0,
            number=1, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='status', full_name='response.status', index=1,
            number=2, type=5, cpp_type=1, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='status_text', full_name='response.status_text', index=2,
            number=3, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='headers', full_name='response.headers', index=3,
            number=4, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='remote_ip', full_name='response.remote_ip', index=4,
            number=5, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='remote_port', full_name='response.remote_port', index=5,
            number=6, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='protocol', full_name='response.protocol', index=6,
            number=7, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='body', full_name='response.body', index=7,
            number=8, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    options=None,
    is_extendable=False,
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=146,
    serialized_end=304,
)

_REQUEST_RESPONSE = _descriptor.Descriptor(
    name='request_response',
    full_name='request_response',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='scan_id', full_name='request_response.scan_id', index=0,
            number=1, type=5, cpp_type=1, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='request', full_name='request_response.request', index=1,
            number=2, type=11, cpp_type=10, label=2,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
        _descriptor.FieldDescriptor(
            name='response', full_name='request_response.response', index=2,
            number=3, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            options=None),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    options=None,
    is_extendable=False,
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=306,
    serialized_end=397,
)

_REQUEST.fields_by_name['headers'].message_type = _HEADER
_RESPONSE.fields_by_name['headers'].message_type = _HEADER
_REQUEST_RESPONSE.fields_by_name['request'].message_type = _REQUEST
_REQUEST_RESPONSE.fields_by_name['response'].message_type = _RESPONSE
DESCRIPTOR.message_types_by_name['header'] = _HEADER
DESCRIPTOR.message_types_by_name['request'] = _REQUEST
DESCRIPTOR.message_types_by_name['response'] = _RESPONSE
DESCRIPTOR.message_types_by_name['request_response'] = _REQUEST_RESPONSE

header = _reflection.GeneratedProtocolMessageType('header', (_message.Message,), dict(
    DESCRIPTOR=_HEADER,
    __module__='request_response_pb2'
    # @@protoc_insertion_point(class_scope:header)
))
_sym_db.RegisterMessage(header)

request = _reflection.GeneratedProtocolMessageType('request', (_message.Message,), dict(
    DESCRIPTOR=_REQUEST,
    __module__='request_response_pb2'
    # @@protoc_insertion_point(class_scope:request)
))
_sym_db.RegisterMessage(request)

response = _reflection.GeneratedProtocolMessageType('response', (_message.Message,), dict(
    DESCRIPTOR=_RESPONSE,
    __module__='request_response_pb2'
    # @@protoc_insertion_point(class_scope:response)
))
_sym_db.RegisterMessage(response)

request_response = _reflection.GeneratedProtocolMessageType('request_response', (_message.Message,), dict(
    DESCRIPTOR=_REQUEST_RESPONSE,
    __module__='request_response_pb2'
    # @@protoc_insertion_point(class_scope:request_response)
))
_sym_db.RegisterMessage(request_response)

# @@protoc_insertion_point(module_scope)
