# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: scan_start.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='scan_start.proto',
    package='',
    syntax='proto2',
    serialized_options=None,
    serialized_pb=_b(
        '\n\x10scan_start.proto\"\x1b\n\x06\x64\x65vice\x12\x11\n\tdevice_id\x18\x01 \x02(\t\"m\n\nscan_start\x12\x0f\n\x07scan_id\x18\x01 \x02(\x05\x12\x10\n\x08platform\x18\x02 \x02(\t\x12\x14\n\x0cpackage_name\x18\x03 \x02(\t\x12\x0c\n\x04\x66ile\x18\x04 \x02(\x0c\x12\x18\n\x07\x64\x65vices\x18\x05 \x03(\x0b\x32\x07.device')
)

_DEVICE = _descriptor.Descriptor(
    name='device',
    full_name='device',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='device_id', full_name='device.device_id', index=0,
            number=1, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto2',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=20,
    serialized_end=47,
)

_SCAN_START = _descriptor.Descriptor(
    name='scan_start',
    full_name='scan_start',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='scan_id', full_name='scan_start.scan_id', index=0,
            number=1, type=5, cpp_type=1, label=2,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='platform', full_name='scan_start.platform', index=1,
            number=2, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='package_name', full_name='scan_start.package_name', index=2,
            number=3, type=9, cpp_type=9, label=2,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='file', full_name='scan_start.file', index=3,
            number=4, type=12, cpp_type=9, label=2,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='devices', full_name='scan_start.devices', index=4,
            number=5, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto2',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=49,
    serialized_end=158,
)

_SCAN_START.fields_by_name['devices'].message_type = _DEVICE
DESCRIPTOR.message_types_by_name['device'] = _DEVICE
DESCRIPTOR.message_types_by_name['scan_start'] = _SCAN_START
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

device = _reflection.GeneratedProtocolMessageType('device', (_message.Message,), dict(
    DESCRIPTOR=_DEVICE,
    __module__='scan_start_pb2'
    # @@protoc_insertion_point(class_scope:device)
))
_sym_db.RegisterMessage(device)

scan_start = _reflection.GeneratedProtocolMessageType('scan_start', (_message.Message,), dict(
    DESCRIPTOR=_SCAN_START,
    __module__='scan_start_pb2'
    # @@protoc_insertion_point(class_scope:scan_start)
))
_sym_db.RegisterMessage(scan_start)

# @@protoc_insertion_point(module_scope)
